@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003 The Ochusha Project.
+ * Copyright (c) 2003-2004 The Ochusha Project.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_ui.c,v 1.79 2004/01/13 01:23:07 fuyu Exp $
+ * $Id: bbs_thread_ui.c,v 1.82 2004/01/14 14:44:30 fuyu Exp $
  */
 
 #include "config.h"
@@ -801,13 +801,10 @@ open_bbs_thread(OchushaApplication *application, OchushaBBSThread *thread,
 	    G_OBJECT(buffer)->ref_count);
 #endif
       /* öref_count䤹 */
-    OCHU_OBJECT_REF(G_OBJECT(buffer));
-    OCHU_OBJECT_REF(G_OBJECT(tab_label));
-    OCHU_OBJECT_REF(G_OBJECT(thread_view));
-#if 0
-    fprintf(stderr, "#1: thread_view(%p)->ref_count=%d\n",
-	    thread_view, G_OBJECT(thread_view)->ref_count);
-#endif
+    OCHU_OBJECT_REF(buffer);
+    g_object_ref(tab_label);		/* бǧ */
+    g_object_ref(thread_view);		/* бǧ */
+
     commit_job(job);
   }
   BBS_THREAD_UI_UNLOCK;
@@ -899,6 +896,8 @@ link_mouse_over_cb(BBSThreadView *view, GdkEventMotion *event,
 		   OchushaApplication *application)
 {
   GtkStatusbar *statusbar = application->statusbar;
+  gchar *tmp_link;
+  gchar tmp_buffer[PATH_MAX];
 
   if (message_id != 0)
     {
@@ -910,12 +909,25 @@ link_mouse_over_cb(BBSThreadView *view, GdkEventMotion *event,
   if (strncmp(link, "<RES>", 5) == 0)
     return FALSE;
 
+  g_strlcpy(tmp_buffer, link, PATH_MAX);
+
+  tmp_link = strstr(tmp_buffer, "<FAKE>");
   if (application->enable_popup_response)
-    show_popup(application, thread, link, event->x_root, event->y_root, view);
+    {
+      if (tmp_link != NULL)
+	show_popup(application, thread,
+		   tmp_link + 6, event->x_root, event->y_root, view);
+      else
+	show_popup(application, thread,
+		   tmp_buffer, event->x_root, event->y_root, view);
+    }
+
+  if (tmp_link != NULL)
+    *tmp_link = '\0';
 
   stack_depth++;
   if (stack_depth == 1)
-    message_id = gtk_statusbar_push(statusbar, link_field_id, link);
+    message_id = gtk_statusbar_push(statusbar, link_field_id, tmp_buffer);
 
   return FALSE;
 }
@@ -1033,9 +1045,12 @@ ensure_popup_context(BBSThreadView *parent, OchushaBBSThread *thread,
   g_object_set_qdata_full(G_OBJECT(parent), popup_context_id, popup_context,
 			  (GDestroyNotify)popup_context_free);
 
-  /* "\357\274\214\343\200\201"  "" UTF-8ɽ */
+  /* "\357\274\214\343\200\201\357\274\235"  "" UTF-8ɽ */
+  /* "\357\274\220"""UTF-8ɽ */
+  /* "\357\274\221"""UTF-8ɽ */
+  /* "\357\274\231"""UTF-8ɽ */
   if (regcomp(&renderer_context->comma_separated_link_pattern,
-	      "^[,\357\274\214\343\200\201][ ]*([1-9][0-9]*)(-[1-9][0-9]*)?",
+	      "^[,=\357\274\214\343\200\201\357\274\235][ ]*([1-9\357\274\221-\357\274\231][0-9\357\274\220-\357\274\231]*)(-[1-9\357\274\221-\357\274\231][0-9\357\274\220-\357\274\231]*)?",
 	      REG_EXTENDED))
     {
       fprintf(stderr, "invalid regular expression\n");
@@ -1043,7 +1058,7 @@ ensure_popup_context(BBSThreadView *parent, OchushaBBSThread *thread,
 
   /* "\357\274\236\342\211\253"  "" UTF-8ɽ */
   if (regcomp(&renderer_context->informal_link_pattern,
-	      "[>\357\274\236\342\211\253]+[ ]*([1-9][0-9]*)(-[1-9][0-9]*)?",
+	      "[>\357\274\236\342\211\253]+[ ]*([1-9\357\274\221-\357\274\231][0-9\357\274\220-\357\274\231]*)(-[1-9\357\274\221-\357\274\231][0-9\357\274\220-\357\274\231]*)?",
 	      REG_EXTENDED))
     {
       fprintf(stderr, "invalid regular expression\n");
@@ -1187,6 +1202,8 @@ link_mouse_press_cb(BBSThreadView *view, GdkEventButton *event,
 		    OchushaBBSThread *thread, const gchar *link,
 		    OchushaApplication *application)
 {
+  gchar *tmp_link;
+
   if (link == NULL)
     return FALSE;
 
@@ -1214,8 +1231,14 @@ link_mouse_press_cb(BBSThreadView *view, GdkEventButton *event,
 					   event->button,
 					   gtk_get_current_event_time());
 	}
+      return TRUE;
     }
-  else if (event->button == 3)
+
+  tmp_link = strstr(link, "<FAKE>");
+  if (tmp_link != NULL)
+    link = tmp_link + 6;
+
+  if (event->button == 3)
     gtk_item_factory_popup_with_data(link_popup_menu_item_factory,
 				     G_STRDUP(link),
 				     link_popup_menu_destructed_cb,
@@ -1226,6 +1249,7 @@ link_mouse_press_cb(BBSThreadView *view, GdkEventButton *event,
     {
       unsigned int from;
       unsigned int to;
+
       if (ochusha_bbs_thread_check_url(thread, link, &from, &to))
 	{
 	  /* URL */
@@ -1405,7 +1429,7 @@ save_initial_thread_view_position(BBSThreadView *view, BBSThreadGUIInfo *info,
   ScrollToMarkArgs *args;
   g_return_if_fail(IS_BBS_THREAD_VIEW(view) && info != NULL && mark != NULL);
 
-  args = G_NEW0(ScrollToMarkArgs, 1);
+  args = g_new0(ScrollToMarkArgs, 1);
   info->next_mark = mark;
   args->view = view;
   args->info = info;
@@ -1616,8 +1640,11 @@ render_bbs_thread(WorkerThread *employee, gpointer args)
   };
 
   /* "\357\274\214\343\200\201\357\274\235"  "" UTF-8ɽ */
+  /* "\357\274\220"""UTF-8ɽ */
+  /* "\357\274\221"""UTF-8ɽ */
+  /* "\357\274\231"""UTF-8ɽ */
   if (regcomp(&context.comma_separated_link_pattern,
-	      "^[,=\357\274\214\343\200\201\357\274\235][ ]*([1-9][0-9]*)(-[1-9][0-9]*)?",
+	      "^[,=\357\274\214\343\200\201\357\274\235][ ]*([1-9\357\274\221-\357\274\231][0-9\357\274\220-\357\274\231]*)(-[1-9\357\274\221-\357\274\231][0-9\357\274\220-\357\274\231]*)?",
 	      REG_EXTENDED))
     {
       fprintf(stderr, "invalid regular expression\n");
@@ -1625,7 +1652,7 @@ render_bbs_thread(WorkerThread *employee, gpointer args)
 
   /* "\357\274\236\342\211\253"  "" UTF-8ɽ */
   if (regcomp(&context.informal_link_pattern,
-	      "[>\357\274\236\342\211\253]+[ ]*([1-9][0-9]*)(-[1-9][0-9]*)?",
+	      "[>\357\274\236\342\211\253]+[ ]*([1-9\357\274\221-\357\274\231][0-9\357\274\220-\357\274\231]*)(-[1-9\357\274\221-\357\274\231][0-9\357\274\220-\357\274\231]*)?",
 	      REG_EXTENDED))
     {
       fprintf(stderr, "invalid regular expression\n");
@@ -1812,14 +1839,13 @@ render_bbs_thread(WorkerThread *employee, gpointer args)
 
   iconv_close(context.handler.converter);
 
-  OCHU_OBJECT_UNREF(G_OBJECT(buffer));
+  OCHU_OBJECT_UNREF(buffer);
 
   OCHU_THREADS_ENTER();
 
   if (job_args->tab_label != NULL)
-    OCHU_OBJECT_UNREF(G_OBJECT(job_args->tab_label));
-
-  OCHU_OBJECT_UNREF(G_OBJECT(job_args->view));
+    g_object_unref(job_args->tab_label);	/* бǧ */
+  g_object_unref(job_args->view);		/* бǧ */
 
   if (info->message_id != 0)
     {
@@ -1838,7 +1864,6 @@ render_bbs_thread(WorkerThread *employee, gpointer args)
   }
   BBS_THREAD_UI_UNLOCK;
 
-  /* "\357\274\214\343\200\201"  "" UTF-8ɽ */
   regfree(&context.comma_separated_link_pattern);
   regfree(&context.informal_link_pattern);
 
@@ -1998,7 +2023,34 @@ render_response(OchushaBBSThread *real_thread, int number,
 
   if (!a_bone)
     {
-      if (response->mailto == NULL)
+      gchar internal_mailto[PATH_MAX];
+      int res_num = 0;
+      char *link = NULL;
+      const gchar *tmp_name = response->name;
+
+      if (response->name[0] != '\0'
+	  && reverse_strpbrk(tmp_name, "0123456789") == NULL
+	  && sscanf(tmp_name, "%d", &res_num) == 1
+	  && (link = ochusha_bbs_thread_get_url_for_response(thread, res_num,
+							     res_num)) != NULL)
+	{
+	  /* ̾󤬿ξ */
+	  if (response->mailto == NULL)
+	    snprintf(internal_mailto, PATH_MAX, "<FAKE>%s", link);
+	  else
+	    snprintf(internal_mailto, PATH_MAX,
+		     "%s<FAKE>%s", response->mailto, link);
+	  G_FREE(link);
+	}
+      else
+	{
+	  if (response->mailto == NULL)
+	    internal_mailto[0] = '\0';
+	  else
+	    g_strlcpy(internal_mailto, response->mailto, PATH_MAX);
+	}
+
+      if (internal_mailto[0] == '\0')
 	{
 	  bbs_thread_view_push_tag(view, context->response_name_tag);
 	  bbs_thread_view_push_tag(view, context->bold_tag);
@@ -2015,9 +2067,17 @@ render_response(OchushaBBSThread *real_thread, int number,
 					    context->handler.helper);
 	  gchar *mailto = convert_string(context->handler.converter,
 					 context->handler.helper,
-					 response->mailto, -1);
+					 internal_mailto, -1);
 	  bbs_thread_view_push_tag(view, context->response_name_tag);
-	  if (strcmp(response->mailto, "sage") != 0)
+	  if (response->mailto == NULL)
+	    {
+	      bbs_thread_view_push_tag(view, context->bold_tag);
+	      bbs_thread_view_append_text_as_hidden_link(view, name, -1,
+						(mailto != NULL
+						 ? mailto : _("broken here")));
+	      bbs_thread_view_pop_tags(view, context->bold_tag);
+	    }
+	  else if (strcmp(response->mailto, "sage") != 0)
 	    bbs_thread_view_append_text_as_link(view, name, -1,
 						(mailto != NULL
 						 ? mailto : _("broken here")));
@@ -2032,7 +2092,12 @@ render_response(OchushaBBSThread *real_thread, int number,
 	      bbs_thread_view_append_text(view, " [", 2);
 	      
 	      if (mailto != NULL)
-		tmp_mailto = simple_string_canon(mailto, -1, NULL, NULL);
+		{
+		  tmp_mailto = strstr(mailto, "<FAKE>");
+		  if (tmp_mailto != NULL)
+		    *tmp_mailto = '\0';
+		  tmp_mailto = simple_string_canon(mailto, -1, NULL, NULL);
+		}
 	      else
 		tmp_mailto = NULL;
 
@@ -2446,7 +2511,7 @@ characters_cb(void *user_data, const char *ch, int len)
 	      context->number_of_gt_characters = 0;
 	    }
 	  else
-	    text = g_strndup(ch, len);
+	    text = G_STRNDUP(ch, len);
 
 	  text_top = text;
 
@@ -2463,18 +2528,14 @@ characters_cb(void *user_data, const char *ch, int len)
 
 		  if (match[1].rm_so != -1 && match[1].rm_eo != match[1].rm_so)
 		    {
-		      char *from_string = g_strndup(text_top + match[1].rm_so,
-						    match[1].rm_eo - match[1].rm_so);
-		      sscanf(from_string, "%d", &from);
-		      g_free(from_string);
+		      from = parse_int(text_top + match[1].rm_so,
+				       match[1].rm_eo - match[1].rm_so);
 		    }
 
 		  if (match[2].rm_so != -1 && match[2].rm_eo != match[2].rm_so)
 		    {
-		      char *to_string = g_strndup(text_top + match[2].rm_so + 1,
-						  match[2].rm_eo - match[2].rm_so - 1);
-		      sscanf(to_string, "%d", &to);
-		      g_free(to_string);
+		      to = parse_int(text_top + match[2].rm_so + 1,
+				     match[2].rm_eo - match[2].rm_so - 1);
 		    }
 		  else
 		    to = from;
@@ -2512,7 +2573,7 @@ characters_cb(void *user_data, const char *ch, int len)
 		{
 		  int no_match_len = match[0].rm_so;
 		  int match_len = match[0].rm_eo - match[0].rm_so;
-		  int from;
+		  int from = 0;
 		  int to;
 		  char *link;
 
@@ -2522,18 +2583,14 @@ characters_cb(void *user_data, const char *ch, int len)
 
 		  if (match[1].rm_so != -1 && match[1].rm_eo != match[1].rm_so)
 		    {
-		      char *from_string = g_strndup(text_top + match[1].rm_so,
-						    match[1].rm_eo - match[1].rm_so);
-		      sscanf(from_string, "%d", &from);
-		      g_free(from_string);
+		      from = parse_int(text_top + match[1].rm_so,
+				       match[1].rm_eo - match[1].rm_so);
 		    }
 
 		  if (match[2].rm_so != -1 && match[2].rm_eo != match[2].rm_so)
 		    {
-		      char *to_string = g_strndup(text_top + match[2].rm_so + 1,
-						  match[2].rm_eo - match[2].rm_so - 1);
-		      sscanf(to_string, "%d", &to);
-		      g_free(to_string);
+		      to = parse_int(text_top + match[2].rm_so + 1,
+				     match[2].rm_eo - match[2].rm_so - 1);
 		    }
 		  else
 		    to = from;
@@ -2580,7 +2637,7 @@ characters_cb(void *user_data, const char *ch, int len)
 	    }
 
 	  if (text != NULL)
-	    g_free(text);
+	    G_FREE(text);
 	}
       return;
     }
@@ -3276,30 +3333,13 @@ refresh_thread(OchushaApplication *application, GtkWidget *widget,
     job->job = render_bbs_thread;
     job->args = job_args;
 
-#if DEBUG_ASYNC_BUFFER_MOST
-    fprintf(stderr, "refresh_thread: ref AsyncBuffer(%p)\n", buffer);
-    fprintf(stderr, "* before unref: buffer->ref_count=%d\n",
-	    G_OBJECT(buffer)->ref_count);
-#endif
-    OCHU_OBJECT_REF(G_OBJECT(buffer));
-    OCHU_OBJECT_REF(G_OBJECT(tab_label));
-    OCHU_OBJECT_REF(G_OBJECT(view));
-#if 0
-    fprintf(stderr, "#2: thread_view(%p)->ref_count=%d\n",
-	    view, G_OBJECT(view)->ref_count);
-#endif
+    OCHU_OBJECT_REF(buffer);
+    g_object_ref(tab_label);	/* бǧ */
+    OCHU_OBJECT_REF(view);
     commit_job(job);
 
     if (old_buffer != NULL)
-      {
-#if DEBUG_ASYNC_BUFFER_MOST
-	fprintf(stderr, "refresh_thread: unref AsyncBuffer(%p)\n",
-		old_buffer);
-	fprintf(stderr, "* before unref: old_buffer->ref_count=%d\n",
-		G_OBJECT(old_buffer)->ref_count);
-#endif
-	OCHU_OBJECT_UNREF(G_OBJECT(old_buffer));
-      }
+      OCHU_OBJECT_UNREF(old_buffer);
   }
 
  finish_refresh:
