@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003 The Ochusha Project.
+ * Copyright (c) 2003-2004 The Ochusha Project.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_view.c,v 1.38 2004/01/13 14:54:46 fuyu Exp $
+ * $Id: bbs_thread_view.c,v 1.41 2004/01/14 11:07:02 fuyu Exp $
  */
 
 #include "config.h"
@@ -55,6 +55,7 @@
 
 static GtkTextTag *get_alt_link_tag(BBSThreadView *view);
 static GtkTextTag *get_alt_sage_tag(BBSThreadView *view);
+static GtkTextTag *get_alt_hidden_link_tag(BBSThreadView *view);
 static void bbs_thread_view_class_init(BBSThreadViewClass *klass);
 static void bbs_thread_view_init(BBSThreadView *view);
 static void bbs_thread_view_finalize(GObject *object);
@@ -145,6 +146,7 @@ static GtkTextTagTable *default_tag_table;
 
 static GtkTextTag *link_tags[2];
 static GtkTextTag *sage_tags[2];
+static GtkTextTag *hidden_link_tags[2];
 
 
 static GtkTextTag *
@@ -165,6 +167,15 @@ get_alt_sage_tag(BBSThreadView *view)
 }
 
 
+static GtkTextTag *
+get_alt_hidden_link_tag(BBSThreadView *view)
+{
+  GtkTextTag *hidden_link_tag = hidden_link_tags[view->alt_hidden_link_tag];
+  view->alt_hidden_link_tag = (view->alt_hidden_link_tag + 1) & 1;
+  return hidden_link_tag;
+}
+
+
 GtkTextTagTable *
 bbs_thread_view_class_get_default_tag_table(BBSThreadViewClass *klass)
 {
@@ -252,6 +263,18 @@ bbs_thread_view_class_init(BBSThreadViewClass *klass)
   gtk_text_tag_table_add(default_tag_table, tag);
   sage_tags[1] = tag;
 
+  /*
+   * ƱΥʣϢ³Ƥ硢GtkTextBufferǸʬĤʤ
+   * Τǡ2(hidden0hidden1)ߤ˻ȤƱ˰
+   */
+  tag = gtk_text_tag_new("hidden0");
+  gtk_text_tag_table_add(default_tag_table, tag);
+  hidden_link_tags[0] = tag;
+
+  tag = gtk_text_tag_new("hidden1");
+  gtk_text_tag_table_add(default_tag_table, tag);
+  hidden_link_tags[1] = tag;
+
   tag = gtk_text_tag_new("response_paragraph");
   g_object_set(G_OBJECT(tag),
 	       "indent", 0,
@@ -515,7 +538,7 @@ bbs_thread_view_finalize(GObject *object)
 
   if (view->text_buffer != NULL)
     {
-      OCHU_OBJECT_UNREF(G_OBJECT(view->text_buffer));
+      OCHU_OBJECT_UNREF(view->text_buffer);
       view->text_buffer = NULL;
     }
   if (view->tags != NULL)
@@ -675,7 +698,24 @@ text_view_get_iter_at_link_tag_from_event(GtkTextView *text_view,
       /* Ƭ˰ư */
       return gtk_text_iter_backward_to_tag_toggle(iter, sage_tags[1]);
     }
-    return FALSE;
+  else if (gtk_text_iter_has_tag(iter, hidden_link_tags[0]))
+    {	/* hidden_link_tags[0]ǰϤޤƤϰϤؤƤ */
+      if (gtk_text_iter_begins_tag(iter, hidden_link_tags[0]))
+	return TRUE;	/* ƬؤƤ */
+
+      /* Ƭ˰ư */
+      return gtk_text_iter_backward_to_tag_toggle(iter, hidden_link_tags[0]);
+    }
+  else if (gtk_text_iter_has_tag(iter, hidden_link_tags[1]))
+    {	/* hidden_link_tags[1]ؤƤ */
+      if (gtk_text_iter_begins_tag(iter, hidden_link_tags[1]))
+	return TRUE;	/* ƬؤƤ */
+
+      /* Ƭ˰ư */
+      return gtk_text_iter_backward_to_tag_toggle(iter, hidden_link_tags[1]);
+    }
+  
+  return FALSE;
 }
 
 
@@ -1059,7 +1099,7 @@ bbs_thread_view_append_text(BBSThreadView *view, const gchar *text, int len)
 
 /*
  * MEMO: textlen byteʬ󥯤äݤɽʸȤƥХåե
- *       linkȤʸϸ˥ʥΰȤƻȤͽꡣ
+ *       linkȤʸϸ˥ʥΰȤƻȤ롣
  *       textˤ"link"դtextƬʸΥХåե
  *       offsetʸlinkؤΥϥåơ֥Ͽ롣
  */
@@ -1085,8 +1125,8 @@ bbs_thread_view_append_text_as_link(BBSThreadView *view,
 
 /*
  * MEMO: textlen byteʬ󥯤äݤɽʸȤƥХåե
- *       linkȤʸϸ˥ʥΰȤƻȤͽꡣ
- *       textˤ"link"դtextƬʸΥХåե
+ *       linkȤʸϸ˥ʥΰȤƻȤ롣
+ *       textˤ"sage"դtextƬʸΥХåե
  *       offsetʸlinkؤΥϥåơ֥Ͽ롣
  *       Ƥ"sage"ΤߤǤ뤳Ȥɽ뤿ᡢ̾Υ󥯤ȤϿѤ롣
  */
@@ -1110,6 +1150,33 @@ bbs_thread_view_append_text_as_sage(BBSThreadView *view,
 }
 
 
+/*
+ * MEMO: textlen byteʬ򤳤ä󥯤äݤ갷٤ʸȤ
+ *       ХåեƤϡ󥯤äݤʤ
+ *       linkȤʸϸ˥ʥΰȤƻȤ롣
+ *       textˤ"hidden_link"դtextƬʸΥХåե
+ *       offsetʸlinkؤΥϥåơ֥Ͽ롣
+ */
+void
+bbs_thread_view_append_text_as_hidden_link(BBSThreadView *view,
+					   const gchar *text, int len,
+					   const gchar *link)
+{
+  GtkTextIter start;
+  int start_offset;
+
+  g_return_if_fail(IS_BBS_THREAD_VIEW(view) && text != NULL);
+
+  start_offset = gtk_text_iter_get_offset(&view->iter);
+  bbs_thread_view_append_text(view, text, len);
+  gtk_text_buffer_get_iter_at_offset(view->text_buffer, &start, start_offset);
+  gtk_text_buffer_apply_tag(view->text_buffer, get_alt_hidden_link_tag(view),
+			    &start, &view->iter);
+  g_hash_table_insert(view->link_table,
+		      (gpointer)start_offset, G_STRDUP(link));
+}
+
+
 void
 bbs_thread_view_append_widget(BBSThreadView *view, GtkWidget *widget)
 {
@@ -1497,7 +1564,7 @@ bbs_thread_view_make_offset_visible(BBSThreadView *view, int offset)
   GtkTextIter iter;
   gboolean result;
 
-  g_return_if_fail(IS_BBS_THREAD_VIEW(view) && view->text_buffer != NULL)
+  g_return_if_fail(IS_BBS_THREAD_VIEW(view) && view->text_buffer != NULL);
 
   CHECK_THREADS_ENTERED();
 
