@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003 The Ochusha Project.
+ * Copyright (c) 2003-2004 The Ochusha Project.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_view.h,v 1.21 2004/01/11 15:44:11 fuyu Exp $
+ * $Id: bbs_thread_view.h,v 1.23 2004/01/15 02:18:05 fuyu Exp $
  */
 
 #ifndef _BBS_THREAD_VIEW_H_
@@ -103,6 +103,7 @@ struct _BBSThreadView
   regmatch_t *regexp_match;
   guint alt_link_tag		: 1;
   guint alt_sage_tag		: 1;
+  guint alt_hidden_link_tag	: 1;
   guint last_is_new_line	: 1;
 
   guint regexp_available	: 1;
@@ -167,6 +168,9 @@ void bbs_thread_view_append_text_as_link(BBSThreadView *view,
 void bbs_thread_view_append_text_as_sage(BBSThreadView *view,
 					 const gchar *text, int len,
 					 const gchar *link);
+void bbs_thread_view_append_text_as_hidden_link(BBSThreadView *view,
+						const gchar *text, int len,
+						const gchar *link);
 void bbs_thread_view_append_widget(BBSThreadView *view, GtkWidget *widget);
 void bbs_thread_view_insert_widget_at_offset(BBSThreadView *view,
 					     GtkWidget *widget,
