@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003 The Ochusha Project.
+ * Copyright (c) 2003-2004 The Ochusha Project.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: boardlist_ui.c,v 1.73 2004/01/13 15:23:27 fuyu Exp $
+ * $Id: boardlist_ui.c,v 1.75 2004/01/14 23:52:25 fuyu Exp $
  */
 
 #include "config.h"
@@ -247,7 +247,7 @@ ensure_my_folder(OchushaApplication *application)
 				       application->favorites);
     }
 
-#if 0
+#if 1
   if (application->favorites->thread_list == NULL)
     ochusha_bulletin_board_read_threadlist_xml(application->favorites,
 					       &application->config,
@@ -268,7 +268,7 @@ ensure_my_folder(OchushaApplication *application)
 				       application->all_threads);
     }
 
-#if 0
+#if 1
   if (application->all_threads->thread_list == NULL)
     ochusha_bulletin_board_read_threadlist_xml(application->all_threads,
 					       &application->config,
@@ -962,12 +962,12 @@ terminate_threadlist_search(OchushaApplication *application,
   TextSearchWindow *window;
   window = TEXT_SEARCH_WINDOW(application->threadlist_search_window);
   if (window != NULL)
-    OCHU_OBJECT_REF(G_OBJECT(window));
+    OCHU_OBJECT_REF(window);
 
   if (window != NULL)
     {
       text_search_window_response(window, GTK_RESPONSE_CANCEL);
-      OCHU_OBJECT_UNREF(G_OBJECT(window));
+      OCHU_OBJECT_UNREF(window);
     }
 }
 
@@ -1113,7 +1113,7 @@ item_view_being_closed_cb(PanedNotebook *paned_notebook,
    * ȤäƤidleؿλŻλƤȤȤˤʤΤǡ
    * פ
    */
-  OCHU_OBJECT_REF(G_OBJECT(item_view));
+  OCHU_OBJECT_REF(item_view);
 
   /*
    * MEMO: Ĥ褦ȤƤ륹Ρsubject.txtɤ߹ߡפ
@@ -1144,7 +1144,7 @@ item_view_being_closed_cb(PanedNotebook *paned_notebook,
 
   if (buffer != NULL)
     {
-      OCHU_OBJECT_UNREF(G_OBJECT(buffer));
+      OCHU_OBJECT_UNREF(buffer);
 
       if (board == application->favorites)
 	virtual_board_clean_up_threadlist(VIRTUAL_BOARD(board), FALSE);
@@ -1613,7 +1613,7 @@ uri_dropped_cb(BoardlistView *view, OchushaBoardCategory *category,
 							 dropped_board->base_url);
 	  if (tmp_board != NULL)
 	    {
-	      OCHU_OBJECT_REF(G_OBJECT(tmp_board));
+	      OCHU_OBJECT_REF(tmp_board);
 	      ochusha_board_category_remove_board(category, tmp_board);
 	      boardlist_view_remove_board(view, category, tmp_board);
 	    }
@@ -1621,7 +1621,7 @@ uri_dropped_cb(BoardlistView *view, OchushaBoardCategory *category,
 	  ochusha_board_category_add_board(category, dropped_board);
 
 	  if (tmp_board != NULL)
-	    OCHU_OBJECT_UNREF(G_OBJECT(tmp_board));
+	    OCHU_OBJECT_UNREF(tmp_board);
 	  
 	  boardlist_view_add_board(view, dropped_board,
 				   category, board);
@@ -1749,7 +1749,7 @@ build_boardlist(WorkerThread *employee, gpointer args)
 
  cleanup_before_return:
   if (buffer != NULL)
-    OCHU_OBJECT_UNREF(G_OBJECT(buffer));
+    OCHU_OBJECT_UNREF(buffer);
 
   if (pthread_mutex_unlock(&board_list_lock) != 0)
     {
