@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003 The Ochusha Project.
+ * Copyright (c) 2003-2004 The Ochusha Project.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: boardlist_view.c,v 1.30 2004/01/13 14:54:46 fuyu Exp $
+ * $Id: boardlist_view.c,v 1.31 2004/01/14 10:03:17 fuyu Exp $
  */
 
 #include "config.h"
@@ -944,7 +944,7 @@ boardlist_view_finalize(GObject *object)
 #endif
   if (view->model != NULL)
     {
-      OCHU_OBJECT_UNREF(G_OBJECT(view->model));
+      g_object_unref(view->model);	/* ȥ졼ʤΤ̵ */
       view->model = NULL;
     }
 
@@ -1878,7 +1878,7 @@ boardlist_view_open(BoardlistView *view, GSList *category_list,
   gtk_tree_view_set_model(&view->view, GTK_TREE_MODEL(store));
 
   if (view->model != NULL)
-    OCHU_OBJECT_UNREF(G_OBJECT(view->model));
+    g_object_unref(view->model);	/* ȥ졼ʤΤ̵ */
   view->model = GTK_TREE_MODEL(store);
 }
 
