@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003 The Ochusha Project.
+ * Copyright (c) 2003-2004 The Ochusha Project.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bulletin_board_ui.c,v 1.117 2004/01/13 23:00:35 fuyu Exp $
+ * $Id: bulletin_board_ui.c,v 1.122 2004/01/15 03:27:26 fuyu Exp $
  */
 
 #include "config.h"
@@ -49,6 +49,7 @@
 #include "virtual_board.h"
 
 #include "worker.h"
+#include "utils.h"
 
 #include "ts_engine.h"
 
@@ -127,8 +128,8 @@ static void page_switched_cb(PanedNotebook *paned_notebook,
 			     OchushaApplication *application);
 
 static void get_current_thread(OchushaApplication *application,
-			       GtkWidget **view, OchushaBBSThread **thread,
-			       IconLabel **tab_label);
+			       GtkWidget **view_p, OchushaBBSThread **thread_p,
+			       IconLabel **tab_label_p);
 static void write_response_button_cb(GtkWidget *widget,
 				     OchushaApplication *application);
 static void select_font_button_cb(GtkWidget *widget,
@@ -239,7 +240,7 @@ prepare_board_ui_initialization(OchushaApplication *application)
   if (engine->is_busy)
     {
       fprintf(stderr, "Couldn't initialize scheme engine...disabled.\n");
-      OCHU_OBJECT_UNREF(G_OBJECT(engine));
+      OCHU_OBJECT_UNREF(engine);
       engine = NULL;
     }
   else
@@ -1012,10 +1013,10 @@ open_bulletin_board(OchushaApplication *application,
 				    tab_label);
 
     /* Ȥޤǳ */
-    OCHU_OBJECT_REF(G_OBJECT(tab_label));
-    OCHU_OBJECT_REF(G_OBJECT(view));
+    g_object_ref(tab_label);	/* бǧ */
+    g_object_ref(view);		/* бǧ */
     if (info->threadlist_source_buffer != NULL)
-      OCHU_OBJECT_REF(G_OBJECT(info->threadlist_source_buffer));
+      OCHU_OBJECT_REF(info->threadlist_source_buffer);
 
     commit_job(job);
   }
@@ -1204,13 +1205,13 @@ refresh_threadlist_view(OchushaApplication *application,
       
     info->is_busy = TRUE;
     /* λޤǳ */
-    OCHU_OBJECT_REF(G_OBJECT(info->threadlist_source_buffer));
-    OCHU_OBJECT_REF(G_OBJECT(tab_label));
-    OCHU_OBJECT_REF(G_OBJECT(threadlist_view));
+    OCHU_OBJECT_REF(info->threadlist_source_buffer);
+    OCHU_OBJECT_REF(tab_label);
+    OCHU_OBJECT_REF(threadlist_view);
 
     commit_job(job);
     if (old_buffer != NULL)
-      OCHU_OBJECT_UNREF(G_OBJECT(old_buffer));
+      OCHU_OBJECT_UNREF(old_buffer);
   }
   THREAD_LIST_UNLOCK;
 }
@@ -1278,9 +1279,9 @@ redraw_threadlist_view(OchushaApplication *application,
 
     info->is_busy = TRUE;
     /* λޤǳ */
-    OCHU_OBJECT_REF(G_OBJECT(info->threadlist_source_buffer));
-    OCHU_OBJECT_REF(G_OBJECT(tab_label));
-    OCHU_OBJECT_REF(G_OBJECT(threadlist_view));
+    OCHU_OBJECT_REF(info->threadlist_source_buffer);
+    OCHU_OBJECT_REF(tab_label);
+    OCHU_OBJECT_REF(threadlist_view);
 
     commit_job(job);
   }
@@ -1425,7 +1426,7 @@ calculate_weight(OchushaBBSThread *thread, BBSThreadGUIInfo *info, int rank,
 
       if (ts_cell_handle_is_long(result))
 	weight = (int)ts_cell_handle_get_long_value(result);
-      OCHU_OBJECT_UNREF(G_OBJECT(result));
+      OCHU_OBJECT_UNREF(result);
     }
   else
     {
@@ -1661,14 +1662,15 @@ show_threadlist(WorkerThread *employee, gpointer args)
 
   OCHU_THREADS_ENTER();
 
-  OCHU_OBJECT_UNREF(G_OBJECT(view));	/* ⤦ʤʤäƤɤ */
+  /* ⤦ʤʤäƤɤ */
+  g_object_unref(view);				/* бǧ */
   if (job_args->tab_label != NULL)
-    OCHU_OBJECT_UNREF(G_OBJECT(job_args->tab_label));
+    g_object_unref(job_args->tab_label);	/* бǧ */
 
   OCHU_THREADS_LEAVE();
 
   if (buffer != NULL)
-    OCHU_OBJECT_UNREF(G_OBJECT(buffer));
+    OCHU_OBJECT_UNREF(buffer);
 
   G_FREE(args);
 }
@@ -1744,10 +1746,10 @@ update_threadlist_entry_style(OchushaApplication *application,
 	  visual_parameter.background_color
 	    = (int)ts_cell_handle_get_long_value(bg);
 
-	  OCHU_OBJECT_UNREF(G_OBJECT(fg));
-	  OCHU_OBJECT_UNREF(G_OBJECT(bg));
+	  OCHU_OBJECT_UNREF(fg);
+	  OCHU_OBJECT_UNREF(bg);
 	}
-      OCHU_OBJECT_UNREF(G_OBJECT(result));
+      OCHU_OBJECT_UNREF(result);
     }
   else
     {
@@ -1927,6 +1929,7 @@ bookmark_thread(OchushaBulletinBoard *board, OchushaBBSThread *thread,
 
   g_return_if_fail(IS_VIRTUAL_BOARD(board));
 
+  ochusha_bulletin_board_lock_thread_list(board);
   proxy = ochusha_bulletin_board_lookup_bbs_thread_by_id(board, id);
   if (proxy != NULL)
     bookmarked = TRUE;
@@ -1937,6 +1940,7 @@ bookmark_thread(OchushaBulletinBoard *board, OchushaBBSThread *thread,
       board->thread_list = g_slist_append(board->thread_list, proxy);
       bookmarked = FALSE;
     }
+  ochusha_bulletin_board_unlock_thread_list(board);
 
   widget = paned_notebook_get_item_view(PANED_NOTEBOOK(application->contents_window), board);
   if (widget != NULL)
@@ -2193,7 +2197,7 @@ free_response_source_buffer(OchushaBBSThread *thread, gpointer unused)
 
   if (info->response_source_buffer != NULL)
     {
-      OCHU_OBJECT_UNREF(G_OBJECT(info->response_source_buffer));
+      OCHU_OBJECT_UNREF(info->response_source_buffer);
       info->response_source_buffer = NULL;
       info->res_num = 0;
       info->num_shown = 0;
@@ -2247,7 +2251,7 @@ item_view_being_closed_cb(PanedNotebook *paned_notebook,
    * ȤäƤidleؿλŻλƤȤȤˤʤΤǡ
    * פ
    */
-  OCHU_OBJECT_REF(G_OBJECT(item_view));
+  OCHU_OBJECT_REF(item_view);
 
 
   /*
@@ -2409,10 +2413,11 @@ page_switched_cb(PanedNotebook *paned_notebook,
 
 
 static void
-get_current_thread(OchushaApplication *application, GtkWidget **view,
-		   OchushaBBSThread **thread, IconLabel **tab_label)
+get_current_thread(OchushaApplication *application, GtkWidget **view_p,
+		   OchushaBBSThread **thread_p, IconLabel **tab_label_p)
 {
   PanedNotebook *paned_notebook;
+  OchushaBBSThread *thread;
 
   g_return_if_fail(application != NULL
 		   && application->contents_window != NULL);
@@ -2420,23 +2425,25 @@ get_current_thread(OchushaApplication *application, GtkWidget **view,
   paned_notebook = PANED_NOTEBOOK(paned_notebook_get_current_item_view(paned_notebook));
   if (paned_notebook == NULL)
     {
-      if (view != NULL)
-	*view = NULL;
-      if (thread != NULL)
-	*thread = NULL;
+      if (view_p != NULL)
+	*view_p = NULL;
+      if (thread_p != NULL)
+	*thread_p = NULL;
       return;
     }
 
-  if (view != NULL)
+  if (view_p != NULL)
     {
       GtkWidget *bin = paned_notebook_get_current_item_view(paned_notebook);
-      *view = gtk_bin_get_child(GTK_BIN(bin));
+      if (bin != NULL)
+	*view_p = gtk_bin_get_child(GTK_BIN(bin));
     }
-  if (thread != NULL)
-    *thread = (OchushaBBSThread *)paned_notebook_get_current_item(paned_notebook);
-  if (tab_label != NULL)
-    *tab_label = (IconLabel *)paned_notebook_get_tab_label(paned_notebook,
-							   *thread);
+  thread = (OchushaBBSThread *)paned_notebook_get_current_item(paned_notebook);
+  if (thread_p != NULL)
+    *thread_p = thread;
+  if (tab_label_p != NULL)
+    *tab_label_p = (IconLabel *)paned_notebook_get_tab_label(paned_notebook,
+							     thread);
 }
 
 
@@ -2454,21 +2461,6 @@ finalize_bulletin_board_view(OchushaBulletinBoard *board, GtkWidget *widget)
 }
 
 
-static const gchar *
-reverse_strpbrk(const gchar *string, const gchar *charset)
-{
-  const gchar *s = string;
-  while (*s != '\0')
-    {
-      if (strchr(charset, *s) == NULL)
-	return s;
-      s++;
-    }
-
-  return NULL;
-}
-
-
 typedef struct _WriteResponseJobArgs
 {
   OchushaBBSThread *thread;
@@ -2617,7 +2609,7 @@ background_write_response(WorkerThread *employee, gpointer job_args)
 
   G_FREE(args->name);
   G_FREE(args->mailto);
-  G_FREE(args->message);
+  g_free(args->message);
   G_FREE(args);
 }
 
@@ -2632,9 +2624,18 @@ write_dialog_response_cb(GtkWidget *write_dialog, int response_id,
   const gchar *name;
   const gchar *mailto;
   gchar *message;
+  guint message_id = (guint)g_object_get_data(G_OBJECT(write_dialog),
+					      "status_message");
 
   MAIN_THREAD_EVENT_CALLBACK();
 
+  if (message_id != 0)
+    {
+      gtk_statusbar_remove(application->statusbar,
+			   writing_netstat_id, message_id);
+      g_object_set_data(G_OBJECT(write_dialog), "status_message", NULL);
+    }
+
   if (response_id == GTK_RESPONSE_REJECT)
     {
       editor = g_object_get_data(G_OBJECT(write_dialog), "editor");
@@ -2646,14 +2647,6 @@ write_dialog_response_cb(GtkWidget *write_dialog, int response_id,
 
   if (response_id != GTK_RESPONSE_OK)
     {
-      guint message_id = (guint)g_object_get_data(G_OBJECT(write_dialog),
-						  "status_message");
-      if (message_id != 0)
-	{
-	  gtk_statusbar_remove(application->statusbar,
-			       writing_netstat_id, message_id);
-	  g_object_set_data(G_OBJECT(write_dialog), "status_message", NULL);
-	}
       gtk_widget_destroy(write_dialog);
 
       ENTER_MAIN_EVENT_LOOP();
@@ -2697,7 +2690,7 @@ write_dialog_response_cb(GtkWidget *write_dialog, int response_id,
     }
 
   if (message != NULL)
-    G_FREE(message);
+    g_free(message);
 }
 
 
