@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003 The Ochusha Project.
+ * Copyright (c) 2003-2004 The Ochusha Project.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: main.c,v 1.16 2004/01/13 14:54:46 fuyu Exp $
+ * $Id: main.c,v 1.17 2004/01/14 10:02:33 fuyu Exp $
  */
 
 #include "config.h"
@@ -98,7 +98,7 @@ main(int argc, char *argv[])
 #if 0
   {
     int fd = ochusha_config_open_file(&application->config, "log.err",
-				      O_RDWR | O_CREAT);
+				      NULL, O_RDWR | O_CREAT);
     application->log_file = fdopen(fd, "a+");
 
     fprintf(application->log_file, "====== Ochusha invoked ======\n");
@@ -254,6 +254,9 @@ main(int argc, char *argv[])
   terminate_workers();
   xmlCleanupParser();
 
+  if (application->log_file != stderr)
+    fclose(application->log_file);
+
 #if TRACE_MEMORY_USAGE
   OCHU_OBJECT_UNREF(G_OBJECT(application->table));
   application->table = NULL;
@@ -333,8 +336,5 @@ main(int argc, char *argv[])
   dump_objects();
 #endif
 
-  if (application->log_file != stderr)
-    fclose(application->log_file);
-
   return 0;
 }
