@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003 The Ochusha Project.
+ * Copyright (c) 2003-2004 The Ochusha Project.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_ui.c,v 1.80 2004/01/13 02:56:12 fuyu Exp $
+ * $Id: ochusha_ui.c,v 1.85 2004/01/15 03:21:12 fuyu Exp $
  */
 
 #include "config.h"
@@ -841,7 +841,7 @@ get_tab_label(const gchar *label_text)
   GtkWidget *label = icon_label_new(label_text,
 				tab_label_icons[TAB_LABEL_ICON_PREPARATION]);
   g_object_set_qdata_full(G_OBJECT(label), tab_label_icon_counter_id,
-			  G_NEW(int, 1), (GDestroyNotify)TRACE_FREE);
+			  G_NEW0(int, 1), (GDestroyNotify)TRACE_FREE);
   return label;
 }
 
@@ -972,7 +972,6 @@ setup_tab_label_icons(void)
 static void
 delete_event_cb(GtkWidget *widget, GdkEventAny *event, gpointer user_data)
 {
-  MAIN_THREAD_EVENT_CALLBACK();
   on_quit(user_data, 0, widget);
   ENTER_MAIN_EVENT_LOOP();
 }
@@ -1028,6 +1027,7 @@ static void
 on_quit(gpointer data, guint action, GtkWidget *widget)
 {
   OchushaApplication *application = (OchushaApplication *)data;
+  MAIN_THREAD_EVENT_CALLBACK();
   OCHU_THREADS_LEAVE();
   ochusha_async_buffer_suspend_all();
   ochusha_async_buffer_terminate_all();
@@ -1801,6 +1801,9 @@ access_progressed_cb(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer,
   counter = g_object_get_qdata(G_OBJECT(tab_label), tab_label_icon_counter_id);
   *counter = (*counter + 1) % 7;
 
+  if (*counter < 0 || *counter > 6)	/* ǰΤad-hoc˥å */
+    *counter = 0;
+
   OCHU_THREADS_ENTER();
 
   icon_label_set_icon(tab_label,
@@ -1900,7 +1903,11 @@ output_log_cb(OchushaNetworkBroker *broker, const gchar *message,
 #if ENABLE_DEBUG_CONSOLE
   g_return_if_fail(GTK_IS_TEXT_BUFFER(log_buffer));
 
+  OCHU_THREADS_ENTER();
+
   gtk_text_buffer_insert(log_buffer, &log_tail_iter, message, -1);
+
+  OCHU_THREADS_LEAVE();
 #endif
 }
 
@@ -2809,7 +2816,26 @@ debug_console_response_cb(GtkWidget *widget, int response_id, gpointer unused)
   if (widget == NULL)
     return;
 
-  gtk_widget_hide(widget);
+  switch (response_id)
+    {
+    case GTK_RESPONSE_REJECT:
+      {
+	GtkTextIter start_iter;
+	GtkTextIter end_iter;
+	g_return_if_fail(GTK_IS_TEXT_BUFFER(log_buffer));
+
+	gtk_text_buffer_get_start_iter(log_buffer, &start_iter);
+	gtk_text_buffer_get_end_iter(log_buffer, &end_iter);
+	gtk_text_buffer_delete(log_buffer, &start_iter, &end_iter);
+	gtk_text_buffer_get_start_iter(log_buffer, &log_tail_iter);
+      }
+      break;
+
+    case GTK_RESPONSE_OK:
+    default:
+      gtk_widget_hide(widget);
+    }
+
   ENTER_MAIN_EVENT_LOOP();
 }
 
@@ -2830,6 +2856,7 @@ open_debug_console(OchushaApplication *application)
   dialog = gtk_dialog_new_with_buttons(_("Debug Outputs"),
 				       NULL,
 				       GTK_DIALOG_DESTROY_WITH_PARENT,
+				       GTK_STOCK_CLEAR, GTK_RESPONSE_REJECT,
 				       GTK_STOCK_OK, GTK_RESPONSE_OK,
 				       NULL);
   g_signal_connect(G_OBJECT(dialog), "response",
@@ -2974,7 +3001,7 @@ open_about_dialog(OchushaApplication *application)
 	gtk_container_add(GTK_CONTAINER(GTK_DIALOG(about_dialog)->vbox),
 			  gtk_image_new_from_pixbuf(banner));
 
-	label = gtk_label_new("Copyright(c) 2003 The Ochusha Project");
+	label = gtk_label_new("Copyright(c) 2003-2004 The Ochusha Project");
 	gtk_container_add(GTK_CONTAINER(GTK_DIALOG(about_dialog)->vbox),
 			  label);
 
