@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003 The Ochusha Project.
+ * Copyright (c) 2003-2004 The Ochusha Project.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: paned_notebook.c,v 1.18 2004/01/13 14:54:46 fuyu Exp $
+ * $Id: paned_notebook.c,v 1.19 2004/01/14 10:03:17 fuyu Exp $
  */
 
 #include "config.h"
@@ -1334,7 +1334,7 @@ close_nth_page(PanedNotebook *paned_notebook, int page)
       paned_notebook->current_item_view = NULL;
     }
 
-  OCHU_OBJECT_REF(G_OBJECT(widget));
+  OCHU_OBJECT_REF(widget);
 
   g_signal_emit(G_OBJECT(paned_notebook),
 		paned_notebook_signals[ITEM_VIEW_BEING_CLOSED_SIGNAL],
@@ -1374,7 +1374,7 @@ close_nth_page(PanedNotebook *paned_notebook, int page)
 		item,
 		widget);
 
-  OCHU_OBJECT_UNREF(G_OBJECT(widget));
+  OCHU_OBJECT_UNREF(widget);
 
   page = mod_notebook_get_current_page(paned_notebook->item_contents);
   gtk_widget_set_sensitive(paned_notebook->left_arrow, page > 0);
