@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003 The Ochusha Project.
+ * Copyright (c) 2003-2004 The Ochusha Project.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: thread_proxy.c,v 1.7 2004/01/13 14:54:46 fuyu Exp $
+ * $Id: thread_proxy.c,v 1.8 2004/01/14 10:03:18 fuyu Exp $
  */
 
 #include "config.h"
@@ -182,7 +182,7 @@ thread_proxy_finalize(GObject *object)
 
   if (proxy->real_thread != NULL)
     {
-      OCHU_OBJECT_UNREF(G_OBJECT(proxy->real_thread));
+      OCHU_OBJECT_UNREF(proxy->real_thread);
       proxy->real_thread = NULL;
     }
 
@@ -490,7 +490,7 @@ thread_proxy_new_with_thread(OchushaBBSThread *thread)
 				      "id", ochusha_bbs_thread_get_url(thread),
 				      "title", thread->title,
 				      NULL));
-  OCHU_OBJECT_REF(G_OBJECT(thread));
+  OCHU_OBJECT_REF(thread);
   THREAD_PROXY(proxy)->real_thread = thread;
   copy_info_from_real_thread(THREAD_PROXY(proxy));
 
@@ -514,8 +514,8 @@ thread_proxy_set_real_thread(ThreadProxy *proxy, OchushaBBSThread *thread)
   g_return_if_fail(OCHUSHA_IS_BBS_THREAD(thread));
 
   if (proxy->real_thread != NULL)
-    OCHU_OBJECT_UNREF(G_OBJECT(proxy->real_thread));
-  OCHU_OBJECT_REF(G_OBJECT(thread));
+    OCHU_OBJECT_UNREF(proxy->real_thread);
+  OCHU_OBJECT_REF(thread);
   proxy->real_thread = thread;
   copy_info_from_real_thread(proxy);
 }
