@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003 The Ochusha Project.
+ * Copyright (c) 2003-2004 The Ochusha Project.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: threadlist_filter.c,v 1.13 2004/01/13 14:54:46 fuyu Exp $
+ * $Id: threadlist_filter.c,v 1.14 2004/01/14 10:03:18 fuyu Exp $
  */
 
 #include "config.h"
@@ -1312,12 +1312,12 @@ threadlist_filter_setting_finalize(GObject *object)
 
   if (setting->all_rules_model != NULL)
     {
-      OCHU_OBJECT_UNREF(G_OBJECT(setting->all_rules_model));
+      OCHU_OBJECT_UNREF(setting->all_rules_model);
       setting->all_rules_model = NULL;
     }
   if (setting->current_rules_model != NULL)
     {
-      OCHU_OBJECT_UNREF(G_OBJECT(setting->current_rules_model));
+      OCHU_OBJECT_UNREF(setting->current_rules_model);
       setting->current_rules_model = NULL;
     }
 
