@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003 The Ochusha Project.
+ * Copyright (c) 2003-2004 The Ochusha Project.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ugly_gtk2utils.c,v 1.10 2003/12/29 08:47:44 fuyu Exp $
+ * $Id: ugly_gtk2utils.c,v 1.11 2004/01/14 10:03:18 fuyu Exp $
  */
 
 #include "config.h"
@@ -50,7 +50,7 @@ delayed_g_object_unref_real(gpointer data)
   fprintf(stderr, "delayed_g_object_unref_real: data=%p data->ref_count=%d\n",
 	  data, G_OBJECT(data)->ref_count);
 #endif
-  if (G_OBJECT(data)->ref_count > 1)
+  if (((GObject *)data)->ref_count > 1)
     {
 #if DEBUG_REF_COUNT
       fprintf(stderr, "delayed_g_object_unref_real: data=%p is still alive\n",
@@ -72,7 +72,7 @@ delayed_g_object_unref_real(gpointer data)
 
   OCHU_THREADS_ENTER();
 
-  OCHU_OBJECT_UNREF(G_OBJECT(data));
+  OCHU_OBJECT_UNREF(data);
 
   OCHU_THREADS_LEAVE();
 
