@@ -172,13 +172,95 @@ libochusha_marshal_BOOLEAN__OBJECT_INT_STRING (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* VOID:POINTER (marshal.list:4) */
+/* OBJECT:STRING (marshal.list:4) */
+void
+libochusha_marshal_OBJECT__STRING (GClosure     *closure,
+                                   GValue       *return_value,
+                                   guint         n_param_values,
+                                   const GValue *param_values,
+                                   gpointer      invocation_hint,
+                                   gpointer      marshal_data)
+{
+  typedef GObject* (*GMarshalFunc_OBJECT__STRING) (gpointer     data1,
+                                                   gpointer     arg_1,
+                                                   gpointer     data2);
+  register GMarshalFunc_OBJECT__STRING callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+  GObject* v_return;
 
-/* VOID:STRING (marshal.list:5) */
+  g_return_if_fail (return_value != NULL);
+  g_return_if_fail (n_param_values == 2);
 
-/* VOID:VOID (marshal.list:6) */
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_OBJECT__STRING) (marshal_data ? marshal_data : cc->callback);
 
-/* VOID:OBJECT,POINTER (marshal.list:7) */
+  v_return = callback (data1,
+                       g_marshal_value_peek_string (param_values + 1),
+                       data2);
+
+  g_value_set_object_take_ownership (return_value, v_return);
+}
+
+/* OBJECT:INT,STRING,STRING (marshal.list:5) */
+void
+libochusha_marshal_OBJECT__INT_STRING_STRING (GClosure     *closure,
+                                              GValue       *return_value,
+                                              guint         n_param_values,
+                                              const GValue *param_values,
+                                              gpointer      invocation_hint,
+                                              gpointer      marshal_data)
+{
+  typedef GObject* (*GMarshalFunc_OBJECT__INT_STRING_STRING) (gpointer     data1,
+                                                              gint         arg_1,
+                                                              gpointer     arg_2,
+                                                              gpointer     arg_3,
+                                                              gpointer     data2);
+  register GMarshalFunc_OBJECT__INT_STRING_STRING callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+  GObject* v_return;
+
+  g_return_if_fail (return_value != NULL);
+  g_return_if_fail (n_param_values == 4);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_OBJECT__INT_STRING_STRING) (marshal_data ? marshal_data : cc->callback);
+
+  v_return = callback (data1,
+                       g_marshal_value_peek_int (param_values + 1),
+                       g_marshal_value_peek_string (param_values + 2),
+                       g_marshal_value_peek_string (param_values + 3),
+                       data2);
+
+  g_value_set_object_take_ownership (return_value, v_return);
+}
+
+/* VOID:POINTER (marshal.list:6) */
+
+/* VOID:STRING (marshal.list:7) */
+
+/* VOID:VOID (marshal.list:8) */
+
+/* VOID:OBJECT,POINTER (marshal.list:9) */
 void
 libochusha_marshal_VOID__OBJECT_POINTER (GClosure     *closure,
                                          GValue       *return_value,
