@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003 The Ochusha Project.
+ * Copyright (c) 2003-2004 The Ochusha Project.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_async_buffer.c,v 1.22 2004/01/13 22:59:47 fuyu Exp $
+ * $Id: ochusha_async_buffer.c,v 1.24 2004/01/15 02:06:27 fuyu Exp $
  */
 
 #include "config.h"
@@ -152,7 +152,7 @@ static GSList *ochusha_async_buffer_list = NULL;
 #define SIGNAL_GLOBAL_CONDITION						\
   if (pthread_cond_signal(&ochusha_async_buffer_global_condition) != 0)	\
     {									\
-      fprintf(stderr, "Couldn't unlock a mutex.\n");			\
+      fprintf(stderr, "Couldn't signal a condition.\n");		\
       abort();								\
     }
 
@@ -379,7 +379,8 @@ get_sync_object(void)
       return sync_object;
     }
 
-  sync_object = (BufferSyncObject *)G_MALLOC(sizeof(BufferSyncObject));
+  /* Υ֥ȤϽλޤǻȤ󤹡*/
+  sync_object = (BufferSyncObject *)g_malloc(sizeof(BufferSyncObject));
   if (pthread_mutex_init(&sync_object->mutex, NULL) != 0)
     {
       fprintf(stderr, "Couldn't init a mutex.\n");
