@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003 The Ochusha Project.
+ * Copyright (c) 2003-2004 The Ochusha Project.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_board_2ch.c,v 1.31 2004/01/11 22:29:14 fuyu Exp $
+ * $Id: ochusha_board_2ch.c,v 1.34 2004/01/15 02:08:58 fuyu Exp $
  */
 
 #include "config.h"
@@ -377,7 +377,7 @@ ochusha_board_2ch_recover_threadlist(OchushaBulletinBoard *board,
 						     recover_title,
 						     NULL, NULL, NULL,
 						     NULL);
-		  OCHU_OBJECT_UNREF(G_OBJECT(dat_buffer));
+		  OCHU_OBJECT_UNREF(dat_buffer);
 		  thread->number_of_responses_read = 1;
 		  board->thread_list = g_slist_append(board->thread_list,
 						      thread);
@@ -537,7 +537,7 @@ ochusha_board_2ch_lookup_kako_thread_by_url(OchushaBulletinBoard *board,
 						 NULL, NULL, NULL, NULL);
 	      ochusha_async_buffer_suspend(dat_buffer);
 	      ochusha_async_buffer_terminate(dat_buffer);
-	      OCHU_OBJECT_UNREF(G_OBJECT(dat_buffer));
+	      OCHU_OBJECT_UNREF(dat_buffer);
 
 	      if (thread->title != NULL)
 		{
@@ -547,7 +547,7 @@ ochusha_board_2ch_lookup_kako_thread_by_url(OchushaBulletinBoard *board,
 		}
 	      else
 		{
-		  OCHU_OBJECT_UNREF(G_OBJECT(thread));
+		  OCHU_OBJECT_UNREF(thread);
 		  thread = NULL;
 		}
 	    }
@@ -907,9 +907,9 @@ collect_dropped_thread(gpointer data, gpointer user_data)
 	  = g_slist_append(thread->board->dropped_list, thread);
     }
   else
-    OCHU_OBJECT_UNREF(G_OBJECT(data));	/* Ƥ륹thread_list
-					 * Ѥ;פrefƤ롣
-					 */
+    OCHU_OBJECT_UNREF(data);	/* Ƥ륹thread_list
+				 * Ѥ;פrefƤ롣
+				 */
 }
 
 
@@ -918,17 +918,18 @@ undo_thread_ref(gpointer data, gpointer user_data)
 {
   OchushaThread2ch *thread_2ch = OCHUSHA_THREAD_2CH(data);
   if (thread_2ch->alive)
-    OCHU_OBJECT_UNREF(G_OBJECT(data));	/* Ƥ륹thread_list
-					 * Ѥ;פrefƤ롣
-					 */
+    OCHU_OBJECT_UNREF(data);	/* Ƥ륹thread_list
+				 * Ѥ;פrefƤ롣
+				 */
 }
 
 
 static gboolean
 advance_parsing(gpointer data)
 {
+  g_object_set_data(G_OBJECT(data), "checker", NULL);
   ochusha_async_buffer_broadcast((OchushaAsyncBuffer *)data);
-  OCHU_OBJECT_UNREF((GObject *)data);
+  OCHU_OBJECT_UNREF(data);
   return FALSE;
 }
 
@@ -1085,7 +1086,7 @@ refresh_threadlist_by_subject_txt(OchushaBulletinBoard *board,
 		thread->flags &= ~OCHUSHA_BBS_THREAD_DAT_DROPPED;
 		thread->number_of_responses_on_server = n_responses_on_server;
 
-		OCHU_OBJECT_REF(G_OBJECT(thread));
+		OCHU_OBJECT_REF(thread);
 		thread_list = g_slist_append(thread_list, thread);
 
 		if (each_thread_cb != NULL
@@ -1118,16 +1119,22 @@ refresh_threadlist_by_subject_txt(OchushaBulletinBoard *board,
 
 	if (interval > 0)
 	  {
-	    if (!ochusha_async_buffer_wait(buffer))
-	      {
+	    unsigned int old_len = buffer->length;
+	    if (ochusha_async_buffer_is_busy(buffer))
+	      do
+		{
+		  if (!ochusha_async_buffer_wait(buffer))
+		    {
 #if DEBUG_ASYNC_BUFFER_MOST
-		fprintf(stderr, "buffer has been terminated.\n");
+		      fprintf(stderr, "buffer has been terminated.\n");
 #endif
-		goto terminated;
-	      }
+		      goto terminated;
+		    }
+		} while (old_len > buffer->length && !buffer->fixed);
 	  }
 	else
 	  {
+#if 0
 	    if (ochusha_async_buffer_is_busy(buffer))
 	      {
 		/*
@@ -1138,18 +1145,33 @@ refresh_threadlist_by_subject_txt(OchushaBulletinBoard *board,
 		  goto terminated;
 	      }
 	    else
+#endif
 	      {
 		/*
 		 * GUIΥ쥹ݥ󥹤βܻؤ¸
 		 */
-		OCHU_OBJECT_REF(G_OBJECT(buffer));
+#if 0
+		int count = 0;
+#endif
+		OCHU_OBJECT_REF(buffer);
+		g_object_set_data(G_OBJECT(buffer), "checker", buffer);
 		g_idle_add_full(G_PRIORITY_HIGH_IDLE + 15,
 				advance_parsing, buffer, NULL);
-		if (!ochusha_async_buffer_wait(buffer))
-		  goto terminated;
+		do
+		  {
+#if 0
+		    count++;
+#endif
+		    if (!ochusha_async_buffer_wait(buffer))
+		      goto terminated;
+		  } while (g_object_get_data(G_OBJECT(buffer), "checker")
+			   != NULL);
+#if 0
+		fprintf(stderr, "count=%d\n", count);
+#endif
 	      }
+	    interval = ANALYSIS_INTERVAL;
 	  }
-	interval = ANALYSIS_INTERVAL;
 
 	if (status->state == OCHUSHA_NETWORK_BROKER_BUFFER_STATE_CACHE_IS_DIRTY)
 	  {
