@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003 The Ochusha Project.
+ * Copyright (c) 2003-2004 The Ochusha Project.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_board_category.c,v 1.12 2004/01/11 03:04:03 fuyu Exp $
+ * $Id: ochusha_board_category.c,v 1.13 2004/01/14 09:59:48 fuyu Exp $
  */
 
 #include "config.h"
@@ -270,14 +270,14 @@ ochusha_board_category_add_board(OchushaBoardCategory *category,
 
 #if 1	/* Ĥν⹹ */
   if (g_slist_find(category->board_list, board) == NULL)
-    OCHU_OBJECT_REF(G_OBJECT(board));
+    OCHU_OBJECT_REF(board);
   else
     category->board_list = g_slist_remove(category->board_list, board);
   category->board_list = g_slist_append(category->board_list, board);
 #else
   if (g_slist_find(category->board_list, board) == NULL)
     {
-      OCHU_OBJECT_REF(G_OBJECT(board));
+      OCHU_OBJECT_REF(board);
       category->board_list = g_slist_append(category->board_list, board);
     }
 #endif
@@ -295,7 +295,7 @@ ochusha_board_category_remove_board(OchushaBoardCategory *category,
     return;
 
   category->board_list = g_slist_remove(category->board_list, board);
-  OCHU_OBJECT_UNREF(G_OBJECT(board));
+  OCHU_OBJECT_UNREF(board);
 }
 
 
