@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003 The Ochusha Project.
+ * Copyright (c) 2003-2004 The Ochusha Project.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_board_jbbs.c,v 1.9 2004/01/11 22:29:14 fuyu Exp $
+ * $Id: ochusha_board_jbbs.c,v 1.10 2004/01/14 09:59:48 fuyu Exp $
  */
 
 #include "config.h"
@@ -664,9 +664,9 @@ collect_dropped_thread(gpointer data, gpointer user_data)
 	  = g_slist_append(thread->board->dropped_list, thread);
     }
   else
-    OCHU_OBJECT_UNREF(G_OBJECT(data));	/* Ƥ륹thread_list
-					 * Ѥ;פrefƤ롣
-					 */
+    OCHU_OBJECT_UNREF(data);	/* Ƥ륹thread_list
+				 * Ѥ;פrefƤ롣
+				 */
 }
 
 
@@ -675,9 +675,9 @@ undo_thread_ref(gpointer data, gpointer user_data)
 {
   OchushaThread2ch *thread_2ch = OCHUSHA_THREAD_2CH(data);
   if (thread_2ch->alive)
-    OCHU_OBJECT_UNREF(G_OBJECT(data));	/* Ƥ륹thread_list
-					 * Ѥ;פrefƤ롣
-					 */
+    OCHU_OBJECT_UNREF(data);	/* Ƥ륹thread_list
+				 * Ѥ;פrefƤ롣
+				 */
 }
 
 
@@ -830,7 +830,7 @@ refresh_threadlist_by_subject_txt(OchushaBulletinBoard *board,
 		thread->flags &= ~OCHUSHA_BBS_THREAD_DAT_DROPPED;
 		thread->number_of_responses_on_server = n_responses_on_server;
 
-		OCHU_OBJECT_REF(G_OBJECT(thread));
+		OCHU_OBJECT_REF(thread);
 		thread_list = g_slist_append(thread_list, thread);
 
 		if (each_thread_cb != NULL
@@ -1052,7 +1052,7 @@ refresh_threadlist_by_subback_html(OchushaBulletinBoard *board,
 		thread->flags &= ~OCHUSHA_BBS_THREAD_DAT_DROPPED;
 		thread->number_of_responses_on_server = n_responses_on_server;
 
-		OCHU_OBJECT_REF(G_OBJECT(thread));
+		OCHU_OBJECT_REF(thread);
 		thread_list = g_slist_append(thread_list, thread);
 
 		if (each_thread_cb != NULL
