@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003 The Ochusha Project.
+ * Copyright (c) 2003-2004 The Ochusha Project.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_thread_2ch.c,v 1.55 2004/01/13 22:57:05 fuyu Exp $
+ * $Id: ochusha_thread_2ch.c,v 1.58 2004/01/15 02:08:58 fuyu Exp $
  */
 
 #include "config.h"
@@ -731,8 +731,9 @@ extract_2ch_response(char *start_pos, char *eol_pos,
 static gboolean
 advance_parsing(gpointer data)
 {
+  g_object_set_data(G_OBJECT(data), "checker", NULL);
   ochusha_async_buffer_broadcast((OchushaAsyncBuffer *)data);
-  OCHU_OBJECT_UNREF((GObject *)data);
+  OCHU_OBJECT_UNREF(data);
   return FALSE;
 }
 
@@ -1012,6 +1013,7 @@ ochusha_thread_2ch_parse_responses(OchushaBBSThread *thread,
 	  }
 	else
 	  {
+#if 0
 	    if (ochusha_async_buffer_is_busy(buffer))
 	      {
 		/*
@@ -1022,18 +1024,24 @@ ochusha_thread_2ch_parse_responses(OchushaBBSThread *thread,
 		  goto terminated;
 	      }
 	    else
+#endif
 	      {
 		/*
 		 * GUIΥ쥹ݥ󥹤βܻؤ¸
 		 */
-		OCHU_OBJECT_REF(G_OBJECT(buffer));
+		OCHU_OBJECT_REF(buffer);
+		g_object_set_data(G_OBJECT(buffer), "checker", buffer);
 		g_idle_add_full(G_PRIORITY_HIGH_IDLE + 15,
 				advance_parsing, buffer, NULL);
-		if (!ochusha_async_buffer_wait(buffer))
-		  goto terminated;
+		do
+		  {
+		    if (!ochusha_async_buffer_wait(buffer))
+		      goto terminated;
+		  } while (g_object_get_data(G_OBJECT(buffer), "checker")
+			   != NULL);
 	      }
+	    interval = ANALYSIS_INTERVAL;
 	  }
-	interval = ANALYSIS_INTERVAL;
 
 	if (status->state
 	    == OCHUSHA_NETWORK_BROKER_BUFFER_STATE_CACHE_IS_DIRTY)
@@ -1291,7 +1299,7 @@ ochusha_thread_2ch_post_response(OchushaBBSThread *thread,
   if (message != NULL)
     G_FREE(message);
   if (query != NULL)
-    G_FREE(query);
+    g_free(query);
   iconv_close(converter);
 
   return TRUE;
@@ -1310,7 +1318,7 @@ ochusha_thread_2ch_post_response(OchushaBBSThread *thread,
   if (message != NULL)
     G_FREE(message);
   if (query != NULL)
-    G_FREE(query);
+    g_free(query);
   iconv_close(converter);
 
   return FALSE;
