@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003 The Ochusha Project.
+ * Copyright (c) 2003-2004 The Ochusha Project.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_thread_jbbs.c,v 1.25 2004/01/13 22:57:05 fuyu Exp $
+ * $Id: ochusha_thread_jbbs.c,v 1.26 2004/01/14 09:59:48 fuyu Exp $
  */
 
 #include "config.h"
@@ -441,7 +441,7 @@ static gboolean
 advance_parsing(gpointer data)
 {
   ochusha_async_buffer_broadcast((OchushaAsyncBuffer *)data);
-  OCHU_OBJECT_UNREF((GObject *)data);
+  OCHU_OBJECT_UNREF(data);
   return FALSE;
 }
 
@@ -710,7 +710,7 @@ ochusha_thread_jbbs_parse_responses(OchushaBBSThread *thread,
 		/*
 		 * GUIΥ쥹ݥ󥹤βܻؤ¸
 		 */
-		OCHU_OBJECT_REF(G_OBJECT(buffer));
+		OCHU_OBJECT_REF(buffer);
 		g_idle_add_full(G_PRIORITY_HIGH_IDLE + 15,
 				advance_parsing, buffer, NULL);
 		if (!ochusha_async_buffer_wait(buffer))
@@ -1536,8 +1536,8 @@ convert_html_to_dat(WorkerThread *employee, HTML2DATConverterJobArgs *args)
     regex_free(response_pattern);
   if (match_region != NULL)
     regex_region_free(match_region, 1);
-  OCHU_OBJECT_UNREF(G_OBJECT(dat_buffer));
-  OCHU_OBJECT_UNREF(G_OBJECT(args->broker));
+  OCHU_OBJECT_UNREF(dat_buffer);
+  OCHU_OBJECT_UNREF(args->broker);
 }
 
 
@@ -1548,7 +1548,7 @@ unref_html_buffer(OchushaAsyncBuffer *html_buffer)
 #if DEBUG_OCHUSHA_ASYNC_BUFFER_MOST
   fprintf(stderr, "unref_html_buffer: %p\n", html_buffer);
 #endif
-  OCHU_OBJECT_UNREF(G_OBJECT(html_buffer));
+  OCHU_OBJECT_UNREF(html_buffer);
 }
 
 
@@ -1735,8 +1735,8 @@ ochusha_thread_jbbs_fake_responses_source(OchushaThread2ch *thread_2ch,
   job->args = args;
 
   /* åɤΤ˳ */
-  OCHU_OBJECT_REF(G_OBJECT(dat_buffer));
-  OCHU_OBJECT_REF(G_OBJECT(broker));
+  OCHU_OBJECT_REF(dat_buffer);
+  OCHU_OBJECT_REF(broker);
 
   commit_job(job);
 
