@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003 The Ochusha Project.
+ * Copyright (c) 2003-2004 The Ochusha Project.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_utils_2ch.c,v 1.34 2004/01/11 22:29:14 fuyu Exp $
+ * $Id: ochusha_utils_2ch.c,v 1.35 2004/01/14 09:59:48 fuyu Exp $
  */
 
 #include "config.h"
@@ -766,7 +766,7 @@ extract_boards(OchushaBBSTable *table, OchushaBoardCategory *category,
 	  /* ФΥ롼ľηǼĤϸʤġġ*/
 	  if (id == NULL || id[0] == '\0')
 	    {
-	      OCHU_OBJECT_UNREF(G_OBJECT(board));
+	      OCHU_OBJECT_UNREF(board);
 	      board = NULL;
 	      goto search_next;
 	    }
@@ -786,7 +786,7 @@ extract_boards(OchushaBBSTable *table, OchushaBoardCategory *category,
 	      if (winner == board_by_name)
 		{
 		  /* boardϥơ֥ɲäʤ */
-		  OCHU_OBJECT_UNREF(G_OBJECT(board));
+		  OCHU_OBJECT_UNREF(board);
 		  board = NULL;
 		  goto search_next;
 		}
@@ -807,12 +807,12 @@ extract_boards(OchushaBBSTable *table, OchushaBoardCategory *category,
 							   callback_data);
 		  if (!result)
 		    {
-		      OCHU_OBJECT_UNREF(G_OBJECT(board));
+		      OCHU_OBJECT_UNREF(board);
 		      return FALSE;
 		    }
 		}
 	      ochusha_bbs_table_add_board(table, board);
-	      OCHU_OBJECT_UNREF(G_OBJECT(board));
+	      OCHU_OBJECT_UNREF(board);
 	    }
 	}
 
@@ -948,7 +948,7 @@ ochusha_utils_2ch_analyze_bbsmenu(OchushaBBSTable *table,
 				    callback_data);
 
 	    if (!result || category->board_list == NULL)
-	      OCHU_OBJECT_UNREF(G_OBJECT(category));
+	      OCHU_OBJECT_UNREF(category);
 	    else
 	      {
 		category->killed = FALSE;
